## 6.1.0.20250717 (2025-07-17)

[stubsabot] Bump cachetools to 6.1.* (#14291)

Release: https://pypi.org/pypi/cachetools/6.1.0
Homepage: https://github.com/tkem/cachetools/
Repository: https://github.com/tkem/cachetools
Typeshed stubs: https://github.com/python/typeshed/tree/main/stubs/cachetools
Diff: https://github.com/tkem/cachetools/compare/v6.0.0...v6.1.0

Stubsabot analysis of the diff between the two releases:
 - Total lines of Python code added: 194.
 - Total lines of Python code deleted: 87.

## 6.0.0.20250525 (2025-05-25)

Bump cachetools to 6.0.* (#14131)

## 5.5.0.20240820 (2024-08-20)

Bump cachetools to 5.5.* (#12556)

## 5.4.0.20240717 (2024-07-17)

Bump cachetools to 5.4.* (#12353)

## 5.3.0.7 (2023-10-27)

Remove many redundant inheritances from `Generic[]` (#10933)

## 5.3.0.6 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 5.3.0.5 (2023-03-27)

Add defaults for third-party stubs A-D (#9952)

## 5.3.0.4 (2023-02-26)

Improve many `__(a)exit__` annotations (#9696)

## 5.3.0.3 (2023-02-23)

Remove unused `type: ignore` comments (#9801)

## 5.3.0.2 (2023-02-22)

Update `Unused` parameters in `stubs/` (#9704)

* Update _Unused TypeAlias

* Update `object | None` params

* Replace unused `object` parameters with `Unused` alias

## 5.3.0.1 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 5.3.0.0 (2023-02-03)

Update `cachetools` stubs to 5.3.* (#9666)

## 5.2.1 (2022-06-26)

Check missing definitions for several packages (#8167)

Co-authored-by: hauntsaninja <>

## 5.2.0 (2022-06-21)

Update cachetools to 5.2.* (#8119)

## 5.0.2 (2022-06-14)

`cachetools`: Fix invalid `TypeVar` usage (#8073)

## 5.0.1 (2022-04-16)

Third-party stubs: import from `collections.abc` where possible (#7637)

## 5.0.0 (2022-03-08)

Update cachetools to 5.0.0 (#7455)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>
Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

## 4.2.10 (2022-03-06)

Upgrade to stubtest with dunder pos only reverted (#7442)

## 4.2.9 (2022-01-12)

Fix cachetools maxsize argument types (#6901)

## 4.2.7 (2021-12-28)

Use PEP 585 syntax wherever possible (#6717)

## 4.2.6 (2021-11-23)

Reduce use of deprecated `typing` aliases (#6358)

## 4.2.5 (2021-11-21)

Fix MutableMapping overrides (#6352)

## 4.2.4 (2021-10-12)

Add star to all non-0.1 versions (#6146)

## 4.2.3 (2021-10-11)

Fix type of lock parameter of cachetools.cachedmethod() decorator (#6144)

## 4.2.2 (2021-09-30)

Remove unncessary MutableMapping overrides (#6097)

## 4.2.1 (2021-09-30)

Add back and update cachetools stubs to cachetools 4.2.4 (#6096)

